<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/badge/OS-Unix-blue.svg?longCache=True)]()

#### Installation
```bash
$ [sudo] pip install gist-recreate
```

#### Pros
+   preserves gist id

#### Scripts usage
command|`usage`
-|-
`gist-recreate` |`usage: gist-recreate path`

#### Examples
```bash
$ cd path/to/gist
$ gist-recreate .
```

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>